@@ -3,10 +3,10 @@
  *
  * Various utilities for AutoGen.
  *
- *  Time-stamp:        "2011-11-25 15:26:20 bkorb"
+ *  Time-stamp:        "2012-03-10 13:11:54 bkorb"
  *
  *  This file is part of AutoGen.
- *  Copyright (c) 1992-2011 Bruce Korb - all rights reserved
+ *  Copyright (c) 1992-2012 Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -29,13 +29,15 @@ define_base_name(void);
 static void
 put_defines_into_env(void);
 
-static void
-start_dep_file(void);
-
 static char const *
-skipQuote(char const * pzQte);
+skip_quote(char const * qstr);
 /* = = = END-STATIC-FORWARD = = = */
 
+/**
+ * Allocating printf function.  It either works or kills the program.
+ * @param[in] pzFmt the input format
+ * @returns the allocated, formatted result string.
+ */
 LOCAL char *
 aprf(char const * pzFmt, ...)
 {
@@ -46,15 +48,17 @@ aprf(char const * pzFmt, ...)
     va_end(ap);
 
     if (pz == NULL) {
-        static char const zMsg[] =
-            "could not allocate for or formatting failed on:\n%s";
-        char z[ sizeof (zMsg) + SCRIBBLE_SIZE ];
-        snprintf(z, sizeof(z), zMsg, pzFmt);
+        char z[ 2 * SCRIBBLE_SIZE ];
+        snprintf(z, sizeof(z), APRF_ALLOCATE_FAIL, pzFmt);
         AG_ABEND(z);
     }
     return pz;
 }
 
+/**
+ * Figure out what base name to use.  --base-name was not specified.
+ * Base it on the definitions file, if available.
+ */
 static void
 define_base_name(void)
 {
@@ -62,7 +66,7 @@ define_base_name(void)
     char* pzD;
 
     if (! ENABLED_OPT(DEFINITIONS)) {
-        OPT_ARG(BASE_NAME) = "baseless";
+        OPT_ARG(BASE_NAME) = DFT_BASE_NAME;
         return;
     }
 
@@ -77,7 +81,7 @@ define_base_name(void)
      *  IF input is from stdin, then use "stdin"
      */
     if ((pz[0] == '-') && (pz[1] == NUL)) {
-        OPT_ARG(BASE_NAME) = "stdin";
+        OPT_ARG(BASE_NAME) = STDIN_FILE_NAME;
         return;
     }
 
@@ -85,12 +89,16 @@ define_base_name(void)
      *  Otherwise, use the basename of the definitions file
      */
     OPT_ARG(BASE_NAME) = \
-        pzD = AGALOC(strlen(pz)+1, "derived base name");
+        pzD = AGALOC(strlen(pz)+1, "derived base");
 
     while ((*pz != NUL) && (*pz != '.'))  *(pzD++) = *(pz++);
     *pzD = NUL;
 }
 
+/**
+ * Put the -D option arguments into the environment.
+ * This makes them accessible to Guile/Scheme code, too.
+ */
 static void
 put_defines_into_env(void)
 {
@@ -111,7 +119,7 @@ put_defines_into_env(void)
             char*  p   = AGALOC(siz, "env define");
 
             strcpy(p, pz);
-            strcpy(p+siz-3, "=1");
+            strcpy(p+siz-3, DFT_ENV_VAL);
             pz = p;
         }
 
@@ -122,74 +130,6 @@ put_defines_into_env(void)
     } while (--ct > 0);
 }
 
-static void
-start_dep_file(void)
-{
-    static char const mkdep_fmt[] =
-        "# Makefile dependency file created by %s\n"
-        "# with the following command:\n";
-
-    char * pz;
-
-    if (pzDepFile == NULL)
-        pzDepFile = aprf("%s.d-XXXXXX", OPT_ARG(BASE_NAME));
-    mkstemp((char *)pzDepFile);
-    pfDepends = fopen(pzDepFile, "w");
-
-    if (pfDepends == NULL)
-        AG_CANT("fopen for write", pzDepFile);
-
-    fprintf(pfDepends, mkdep_fmt, autogenOptions.pzProgName);
-
-    {
-        int     ac = autogenOptions.origArgCt;
-        char ** av = autogenOptions.origArgVect;
-
-        while (ac-- > 0) {
-            char * arg = *(av++);
-            fprintf(pfDepends, "#   %s\n", arg);
-        }
-    }
-
-    if (pzDepTarget == NULL) {
-        char * p;
-        AGDUPSTR(pzDepTarget, pzDepFile, "targ name");
-        p  = (char *)pzDepTarget + strlen(pzDepTarget) - 7;
-        *p = NUL;
-    }
-
-    {
-        static char const tfmt[] = "%s_%s";
-        char const * pnm = autogenOptions.pzPROGNAME;
-        char const * bnm = strchr(pzDepTarget, '/');
-
-        if (bnm != NULL)
-            bnm++;
-        else
-            bnm = pzDepTarget;
-
-        {
-            size_t sz = strlen(pnm) + strlen(bnm) + sizeof(tfmt) - 4;
-
-            pz_targ_base = pz = AGALOC(sz, "mk targ list");
-            sprintf(pz, tfmt, pnm, bnm);
-        }
-    }
-
-    /*
-     * Now scan over the characters in "pz_targ_base".  Anything that
-     * is not a legal name character gets replaced with an underscore.
-     */
-    for (;;) {
-        unsigned int ch = (unsigned int)*(pz++);
-        if (ch == NUL)
-            break;
-        if (! IS_ALPHANUMERIC_CHAR(ch))
-            pz[-1] = '_';
-    }
-    fprintf(pfDepends, "%s_TList =", pz_targ_base);
-}
-
 /**
  *  Open trace output file.
  *
@@ -199,6 +139,9 @@ start_dep_file(void)
  *
  *  The trace output starts with the command and arguments used to
  *  start autogen.
+ *
+ * @param[in] av    autogen's argument vector
+ * @param[in] odsc  option descriptor with file name string argument
  */
 LOCAL void
 open_trace_file(char ** av, tOptDesc * odsc)
@@ -207,40 +150,51 @@ open_trace_file(char ** av, tOptDesc * odsc)
 
     trace_is_to_pipe = (*fname == '|');
     if (trace_is_to_pipe)
-        pfTrace = popen(++fname, "w");
+        trace_fp = popen(++fname, "w");
 
     else if ((fname[0] == '>') && (fname[1] == '>')) {
-        fname += 2;
-        while (IS_WHITESPACE_CHAR((int)(*fname)))  fname++;
-        pfTrace = fopen(fname, "a");
+        fname = SPN_WHITESPACE_CHARS(fname + 2);
+        trace_fp = fopen(fname, "a");
     }
 
     else
-        pfTrace = fopen(fname, "w");
+        trace_fp = fopen(fname, "w");
 
-    if (pfTrace == NULL)
-        AG_ABEND(aprf("Error %d (%s) opening `%s' for output",
-                      errno, strerror(errno), fname));
+    if (trace_fp == NULL)
+        AG_ABEND(aprf(OPEN_ERROR_FMT, errno, strerror(errno), fname));
 
 #ifdef _IONBF
-    setvbuf(pfTrace, NULL, _IONBF, 0);
+    setvbuf(trace_fp, NULL, _IONBF, 0);
 #endif
 
-    fprintf(pfTrace, "\nAutoGen starts:  %s", *av);
+    fprintf(trace_fp, TRACE_START_FMT, (unsigned int)getpid(), *av);
     while (*(++av) != NULL)
-        fprintf(pfTrace, " '%s'", *av);
-    putc(NL, pfTrace);
+        fprintf(trace_fp, TRACE_AG_ARG_FMT, *av);
+    putc(NL, trace_fp);
 }
 
+/**
+ * Check the environment for make dependency info.  We look for
+ * AUTOGEN_MAKE_DEP, but if that is not found, we also look for
+ * DEPENDENCIES_OUTPUT.  To do dependency tracking at all, we
+ * must find one of these environment variables and it must
+ *
+ * * be non-empty
+ * * not contain a variation on "no"
+ * * not contain a variation on "false"
+ *
+ * Furthermore, to specify a file name, the contents must not contain
+ * some variation on "yes" or "true".
+ */
 LOCAL void
 check_make_dep_env(void)
 {
-    ag_bool have_opt_string = AG_FALSE;
-    ag_bool set_opt         = AG_FALSE;
+    bool have_opt_string = false;
+    bool set_opt         = false;
 
-    char const * mdep = getenv("AUTOGEN_MAKE_DEP");
+    char const * mdep = getenv(AG_MAKE_DEP_NAME);
     if (mdep == NULL) {
-        mdep = getenv("DEPENDENCIES_OUTPUT");
+        mdep = getenv(DEP_OUT_NAME);
         if (mdep == NULL)
             return;
     }
@@ -252,36 +206,36 @@ check_make_dep_env(void)
 
     case '0':
         if (mdep[1] != NUL)
-            have_opt_string = AG_TRUE;
+            have_opt_string = true;
         break;
 
     case 'y':
     case 'Y':
-        set_opt = AG_TRUE;
-        have_opt_string = (streqvcmp(mdep + 1, "es") != 0);
+        set_opt = true;
+        have_opt_string = (streqvcmp(mdep + 1, YES_NAME_STR+1) != 0);
         break;
 
     case 'n':
     case 'N':
         set_opt = \
-            have_opt_string = (streqvcmp(mdep + 1, "o") != 0);
+            have_opt_string = (streqvcmp(mdep + 1, NO_NAME_STR+1) != 0);
         break;
 
     case 't':
     case 'T':
-        set_opt = AG_TRUE;
-        have_opt_string = (streqvcmp(mdep + 1, "es") != 0);
+        set_opt = true;
+        have_opt_string = (streqvcmp(mdep + 1, TRUE_NAME_STR+1) != 0);
         break;
 
     case 'f':
     case 'F':
         set_opt = \
-            have_opt_string = (streqvcmp(mdep + 1, "alse") != 0);
+            have_opt_string = (streqvcmp(mdep + 1, FALSE_NAME_STR+1) != 0);
         break;
 
     default:
         have_opt_string = \
-            set_opt = AG_TRUE;
+            set_opt = true;
     }
     if (! set_opt) return;
     if (! have_opt_string) {
@@ -304,9 +258,9 @@ check_make_dep_env(void)
         *pz = NUL;
 
         SET_OPT_SAVE_OPTS(fp);
-
-        while (IS_WHITESPACE_CHAR(*mdep))  mdep++;
-        if (*mdep == NUL) return;
+        mdep = SPN_WHITESPACE_CHARS(mdep);
+        if (*mdep == NUL)
+            return;
 
         pz = fp;
         *(pz++) = 'T';
@@ -324,14 +278,13 @@ check_make_dep_env(void)
 }
 
 LOCAL void
-doOptions(int arg_ct, char ** arg_vec)
+process_ag_opts(int arg_ct, char ** arg_vec)
 {
     /*
      *  Advance the argument counters and pointers past any
      *  command line options
      */
     {
-        static char const one_src[] = "%s ERROR:  Too many definition files\n";
         int  optCt = optionProcess(&autogenOptions, arg_ct, arg_vec);
 
         /*
@@ -346,12 +299,12 @@ doOptions(int arg_ct, char ** arg_vec)
             /* FALLTHROUGH */
 
         default:
-            usage_message(one_src, pzProg);
+            usage_message(DOOPT_TOO_MANY_DEFS, ag_pname);
             /* NOTREACHED */
 
         case 0:
             if (! HAVE_OPT(DEFINITIONS))
-                OPT_ARG(DEFINITIONS) = "-";
+                OPT_ARG(DEFINITIONS) = DFT_DEF_INPUT_STR;
             break;
         }
     }
@@ -359,7 +312,7 @@ doOptions(int arg_ct, char ** arg_vec)
     if ((OPT_VALUE_TRACE > TRACE_NOTHING) && HAVE_OPT(TRACE_OUT))
         open_trace_file(arg_vec, &DESC(TRACE_OUT));
 
-    startTime = time(NULL);
+    start_time = time(NULL) - 1;
 
     if (! HAVE_OPT(TIMEOUT))
         OPT_ARG(TIMEOUT) = (char const *)AG_DEFAULT_TIMEOUT;
@@ -370,7 +323,7 @@ doOptions(int arg_ct, char ** arg_vec)
      */
     if (  (! ENABLED_OPT(DEFINITIONS))
        && (! HAVE_OPT(OVERRIDE_TPL)) )
-        AG_ABEND("no template was specified");
+        AG_ABEND(NO_TEMPLATE_ERR_MSG);
 
     /*
      *  IF we do not have a base-name option, then we compute some value
@@ -392,8 +345,17 @@ doOptions(int arg_ct, char ** arg_vec)
         put_defines_into_env();
 }
 
+/**
+ *  look for a define string.  It may be in our DEFINE option list
+ *  (preferred result) or in the environment.  Look up both.
+ *
+ *  @param[in] de_name   name to look for
+ *  @param[in] check_env whether or not to look in environment
+ *
+ *  @returns a pointer to the string, if found, or NULL.
+ */
 LOCAL char const *
-getDefine(char const * pzDefName, ag_bool check_env)
+get_define_str(char const * de_name, bool check_env)
 {
     char const **   ppz;
     int     ct;
@@ -409,7 +371,7 @@ getDefine(char const * pzDefName, ag_bool check_env)
             if (pzEq != NULL)
                 *pzEq = NUL;
 
-            res = strcmp(pzDefName, pz);
+            res = strcmp(de_name, pz);
             if (pzEq != NULL)
                 *pzEq = '=';
 
@@ -417,41 +379,43 @@ getDefine(char const * pzDefName, ag_bool check_env)
                 return (pzEq != NULL) ? pzEq+1 : zNil;
         }
     }
-    return check_env ? getenv(pzDefName) : NULL;
+    return check_env ? getenv(de_name) : NULL;
 }
 
 
-/*
- *  The following routine scans over quoted text, shifting
- *  it in the process and eliminating the starting quote,
- *  ending quote and any embedded backslashes.  They may
- *  be used to embed the quote character in the quoted text.
- *  The quote character is whatever character the argument
- *  is pointing at when this procedure is called.
+/**
+ *  The following routine scans over quoted text, shifting it in the process
+ *  and eliminating the starting quote, ending quote and any embedded
+ *  backslashes.  They may be used to embed the quote character in the quoted
+ *  text.  The quote character is whatever character the argument is pointing
+ *  at when this procedure is called.
+ *
+ *  @param[in,out] in_q   input quoted string/output unquoted
+ *  @returns the address of the byte after the original closing quote.
  */
-LOCAL char*
-spanQuote(char* pzQte)
+LOCAL char *
+span_quote(char * in_q)
 {
-    char  q = *pzQte;          /*  Save the quote character type */
-    char* p = pzQte++;         /*  Destination pointer           */
+    char   qc = *in_q;          /*  Save the quote character type */
+    char * dp = in_q++;         /*  Destination pointer           */
 
-    while (*pzQte != q) {
-        switch (*p++ = *pzQte++) {
+    while (*in_q != qc) {
+        switch (*dp++ = *in_q++) {
         case NUL:
-            return pzQte-1;      /* Return address of terminating NUL */
+            return in_q-1;      /* Return address of terminating NUL */
 
         case '\\':
-            if (q != '\'') {
-                int ct = ao_string_cook_escape_char(pzQte, p-1, 0x7F);
-                if (p[-1] == 0x7F)  p--;
-                pzQte += ct;
+            if (qc != '\'') {
+                int ct = ao_string_cook_escape_char(in_q, dp-1, 0x7F);
+                if (dp[-1] == 0x7F)  dp--;
+                in_q += ct;
 
             } else {
-                switch (*pzQte) {
+                switch (*in_q) {
                 case '\\':
                 case '\'':
                 case '#':
-                    p[-1] = *pzQte++;
+                    dp[-1] = *in_q++;
                 }
             }
             break;
@@ -461,70 +425,83 @@ spanQuote(char* pzQte)
         }
     }
 
-    *p = NUL;
-    return pzQte+1; /* Return addr of char after the terminating quote */
+    *dp = NUL;
+    return in_q+1; /* Return addr of char after the terminating quote */
 }
 
-/*
- *  The following routine skips over quoted text.
- *  The quote character is whatever character the argument
- *  is pointing at when this procedure is called.
+/**
+ *  The following routine skips over quoted text.  The quote character is
+ *  whatever character the argument is pointing at when this procedure is
+ *  called.
+ *
+ *  @param[in] qstr   input quoted string/output unquoted
+ *  @returns the address of the byte after the original closing quote.
  */
 static char const *
-skipQuote(char const * pzQte)
+skip_quote(char const * qstr)
 {
-    char  q = *pzQte++;        /*  Save the quote character type */
+    char qc = *qstr++;        /*  Save the quote character type */
 
-    while (*pzQte != q) {
-        switch (*pzQte++) {
+    while (*qstr != qc) {
+        switch (*qstr++) {
         case NUL:
-            return pzQte-1;      /* Return address of terminating NUL */
+            return qstr-1;      /* Return address of terminating NUL */
 
         case '\\':
-            if (q == '\'') {
+            if (qc == '\'') {
                 /*
                  *  Single quoted strings process the backquote specially
                  *  only in fron of these three characters:
                  */
-                switch (*pzQte) {
+                switch (*qstr) {
                 case '\\':
                 case '\'':
                 case '#':
-                    pzQte++;
+                    qstr++;
                 }
 
             } else {
                 char p[10];  /* provide a scratch pad for escape processing */
-                int ct = ao_string_cook_escape_char(pzQte, p, 0x7F);
-                pzQte += ct;
+                int ct = ao_string_cook_escape_char(qstr, p, 0x7F);
+                qstr += ct;
             } /* if (q == '\'')      */
-        }     /* switch (*pzQte++)   */
-    }         /* while (*pzQte != q) */
+        }     /* switch (*qstr++)   */
+    }         /* while (*qstr != q) */
 
-    return pzQte+1; /* Return addr of char after the terminating quote */
+    return qstr+1; /* Return addr of char after the terminating quote */
 }
 
-
+/**
+ * Skip over scheme expression.  We need to find what follows it.
+ * Guile will carefully parse it later.
+ *
+ * @param[in]  scan  where to start search
+ * @param[in]  end   point beyond which not to go
+ * @returns    character after closing parenthesis or "end",
+ * which ever comes first.
+ */
 LOCAL char const *
-skipScheme(char const * pzSrc,  char const * pzEnd)
+skip_scheme(char const * scan,  char const * end)
 {
     int  level = 0;
 
     for (;;) {
-        if (pzSrc >= pzEnd)
-            return pzEnd;
-        switch (*(pzSrc++)) {
+        scan = BRK_SCHEME_NOTE_CHARS(scan);
+        if (scan >= end)
+            return end;
+
+        switch (*(scan++)) {
         case '(':
             level++;
             break;
 
         case ')':
             if (--level == 0)
-                return pzSrc;
+                return scan;
             break;
 
         case '"':
-            pzSrc = skipQuote(pzSrc-1);
+            scan = skip_quote(scan-1);
         }
     }
 }
@@ -546,13 +523,13 @@ count_nl(char const * pz)
 
 
 LOCAL char const *
-skipExpression(char const * pzSrc, size_t len)
+skip_expr(char const * pzSrc, size_t len)
 {
     char const * pzEnd = pzSrc + len;
 
  guess_again:
 
-    while (IS_WHITESPACE_CHAR(*pzSrc)) pzSrc++;
+    pzSrc = SPN_WHITESPACE_CHARS(pzSrc);
     if (pzSrc >= pzEnd)
         return pzEnd;
     switch (*pzSrc) {
@@ -563,19 +540,19 @@ skipExpression(char const * pzSrc, size_t len)
         goto guess_again;
 
     case '(':
-        return skipScheme(pzSrc, pzEnd);
+        return skip_scheme(pzSrc, pzEnd);
 
     case '"':
     case '\'':
     case '`':
-        pzSrc = skipQuote(pzSrc);
+        pzSrc = skip_quote(pzSrc);
         return (pzSrc > pzEnd) ? pzEnd : pzSrc;
 
     default:
         break;
     }
 
-    while (! IS_WHITESPACE_CHAR(*pzSrc))  pzSrc++;
+    pzSrc = BRK_WHITESPACE_CHARS(pzSrc);
     return (pzSrc > pzEnd) ? pzEnd : pzSrc;
 }
 /*
