@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Sun Jun 17 15:47:54 PDT 2012
+ * Generated Sat Aug 11 09:41:33 PDT 2012
  */
 #ifndef AGEN5_PROTO_H_GUARD
 #define AGEN5_PROTO_H_GUARD 1
@@ -258,10 +258,10 @@ LOCAL templ_t *
 find_tpl(char const * pzTemplName);
 
 LOCAL tSuccess
-find_file(char const * pzFName,
-          char * pzFullName,
-          char const * const * papSuffixList,
-          char const * pzReferrer);
+find_file(char const * in_name,
+          char *       res_name,
+          char const * const * sfx_list,
+          char const * referring_tpl);
 
 LOCAL templ_t *
 tpl_load(char const * fname, char const * referrer);
